<?php
class UserController extends \BaseController
{
    
    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index() {
        
        // get all users not type admin with pagination of 10
        $users = User::select('users.id', 'username', 'email', 'type', 'name', 'project_name', 'location_name', 'users.updated_at')->join('locations', 'locations.id', '=', 'users.location_id')->join('projects', 'projects.id', '=', 'locations.project_id')->where('locations.status', 'enable')->where('users.id', '<>', Auth::id())->orderBy('users.id', 'desc')->paginate(20);
        
        // pagination links and text
        $data['paginationLinks'] = $users->appends(Input::except('page'))->links();
        $data['paginationText'] = 'Showing ' . $users->getFrom() . ' - ' . $users->getTo() . ' of ' . $users->getTotal();
        
        $data['users'] = $users;
        
        return View::make('user.list', $data);
    }
    
    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create() {
        
        $data = array();
        $data['locationOptions'] = Location::getLocationOptions();
        $data['userTypeOptions'] = User::getUserTypeOptions();
        $data['scripts'] = array('user-form.js');
        return View::make('user.form', $data);
    }
    
    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store() {
        
        // validate post fields
        $rules = array('name' => 'required', 'username' => 'required|unique:users|min:3', 'email' => 'required|email|unique:users', 'password' => 'required|min:6|confirmed', 'password_confirmation' => 'required',);
        
        if (Input::get('type') == 'staff') {
            $rules['location_id'] = 'required';
        }
        
        $errorMessages = array('location_id.required' => 'Project field is required.',);
        
        $validator = Validator::make(Input::all(), $rules, $errorMessages);
        
        // process the add
        if ($validator->fails()) {
            return Redirect::route('user.create')->withErrors($validator)->withInput(Input::all());
        } 
        else {
            
            // get input
            $name = Input::get('name');
            $email = Input::get('email');
            $username = Input::get('username');
            $password = Input::get('password');
            $type = Input::get('type');
            $locationId = Input::get('location_id');
            
            if (Input::get('type') == 'admin') {
                $locationId = 1;
                
                // for admin user
                
                
            }
            
            // create new user with inputs
            $user = new User;
            $user->name = $name;
            $user->password = Hash::make($password);
            $user->username = $username;
            $user->type = $type;
            $user->email = $email;
            $user->location_id = $locationId;
            $user->save();
            
            // redirect to user routing with message
            return Redirect::to('user')->with('message', 'User has been successfully added.');
        }
    }
    
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id) {
    }
    
    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id) {
        
        // throw 404 if not admin and editing other user
        if (Auth::user()->type != 'admin' && Auth::id() != $id) {
            App::abort(404);
        }
        
        $data = array();
        $data['locationOptions'] = Location::getLocationOptions();
        $data['userTypeOptions'] = User::getUserTypeOptions();
        $data['user'] = User::find($id);
        $data['scripts'] = array('user-form.js');
        
        return View::make('user.form', $data);
    }
    
    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id) {
        
        // throw 404 if not admin and editing other user
        if (Auth::user()->type != 'admin' && Auth::id() != $id) {
            App::abort(404);
        }
        
        // validate fields
        $rules = array('name' => 'required', 'email' => 'required|email|unique:users,email,' . $id,);
        
        if ($id == Auth::id() && (strlen(Input::get('old_password')))) {
            $rules['old_password'] = 'required';
            $rules['new_password'] = 'required|min:6|confirmed';
            $rules['new_password_confirmation'] = 'required';
        }
        
        $validator = Validator::make(Input::all(), $rules);
        
        // process the validation
        if ($validator->fails()) {
            return Redirect::to(route('user.edit', $id))->withErrors($validator)->withInput(Input::all());
        } 
        else {
            $name = Input::get('name');
            $email = Input::get('email');
            $location_id = Input::get('location_id');
            $old_password = Input::get('old_password');
            
            // update based on user id
            $user = User::find($id);
            if ($id == Auth::id() && strlen($old_password)) {
                
                // check if old password entered same as current
                if (Hash::check($old_password, $user->password)) {
                    $user->password = Hash::make(Input::get('new_password'));
                } 
                else {
                    return Redirect::route('user.edit', $id)->with('error', 'Old password is incorrect.');
                }
            }
            $user->name = $name;
            $user->email = $email;
            
            $user->save();
            
            // redirect to user with message
            return Redirect::back()->with('message', 'User has been successfully updated.');
        }
    }
    
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id) {
        
        // Change status user to 'disable' instead of delete
        $user = User::find($id);
        $user->status = 'disable';
        $user->save();
        Session::flash('message', 'Record has been successfully deleted');
    }
    
    public function assignLocation($id) {
        $data = array();
        $data['user'] = User::find($id);
        $data['selectedLocation'] = ExtraLocation::where('user_id', $id)->lists('location_id');
        
        $data['locations'] = Location::whereNotIn('id', array($data['user']->location_id, 1))->get();
        
        return View::make('user.location', $data);
    }
    
    public function submitAssignLocation($id) {
        
        $locations = Input::get('locations');
        
        // delete all first before assign new / update
        ExtraLocation::where('user_id', $id)->delete();
        if (count($locations)) {
            foreach ($locations as $location) {
                $extraLocation = new ExtraLocation;
                $extraLocation->user_id = $id;
                $extraLocation->location_id = $location;
                $extraLocation->save();
            }
        }
        return Redirect::back()->with('message', 'Locations have been successfully updated');
    }
}
